# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-01-14 15:47
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0005_auto_20191217_1301'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={},
        ),
    ]



# Generated by Django 2.2.16 on 2020-09-26 09:11

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0014_auto_20200903_1051'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='owner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='owned_customers', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='project',
            name='businessProvider',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djangoldp_project.BusinessProvider'),
        ),
        migrations.AlterField(
            model_name='project',
            name='captain',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='project',
            name='customer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djangoldp_project.Customer'),
        ),
    ]



from django.conf import settings


XMPP_SERVERS = set({'51.15.243.248', '212.47.234.179', '2001:bc8:47b0:2711::1'})

if hasattr(settings, 'XMPP_SERVER_IP'):
    XMPP_SERVERS = XMPP_SERVERS.union(getattr(settings, 'XMPP_SERVER_IP'))


def get_client_ip(request):
    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
    if x_forwarded_for:
        ip = x_forwarded_for.split(',')[0]
    else:
        ip = request.META.get('REMOTE_ADDR')
    return ip



from django.conf.urls import url
from .views import ProjectsJoinableViewset
from .models import Project
from djangoldp.models import Model


urlpatterns = [
    url(r'^projects/joinable/', ProjectsJoinableViewset.urls(model_prefix="projects-joinable",
        model=Project,
        lookup_field=Model.get_meta(Project, 'lookup_field', 'pk'),
        permission_classes=Model.get_meta(Project, 'permission_classes', []),
        fields=Model.get_meta(Project, 'serializer_fields', []),
        nested_fields=Model.get_meta(Project, 'nested_fields', [])))
]
